From 8592d389a65a415462e4bbcc3a09f65cce952940 Mon Sep 17 00:00:00 2001
From: Rudolf Cornelissen
Date: Thu, 18 Mar 2004 13:59:12 +0000
Subject: [PATCH] added DFP aspect correction centering, cutting and
displaymode aspect checking
git-svn-id: file:///srv/svn/repos/haiku/trunk/current@7025 a95241bf-73f2-0310-859d-f6bbb57e9c96
---
src/add-ons/accelerants/nvidia/engine/nv_info.c | 8 +++++---
src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html | 4 ++--
2 files changed, 7 insertions(+), 5 deletions(-)
diff --git a/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html b/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html
index 521f4d0c18..eb6a63f04f 100644
--- a/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html
+++ b/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html
@@ -4,14 +4,14 @@
Changes done for each driverversion:
-head (0.10-7), (Rudolf)
+head (0.10-8), (Rudolf)
- Implemented laptop internal flatpanel presence and native resolution detection;
- Implemented external DVI flatpanel(s) presence and native resolution detection;
- Added flatpanel(s) refreshrate protection: it(they) is(are) always kept at 60Hz refresh;
- Added flatpanel specific CRTC modeline and DFP modeline tuning: DVI connected panels work now on both heads (if applicable);
- Fixed fullscreen overlay on DVI panels;
-
- Added aspect correction programming for widescreen panels;
+
- Added aspect correction programming for flatpanels: corrects if mode aspect differs too much from panel aspect;
- Fixed acceleration engine management regarding sync_to_token: no more updating glitches should occur now.
NOTE:
diff --git a/src/add-ons/accelerants/nvidia/engine/nv_info.c b/src/add-ons/accelerants/nvidia/engine/nv_info.c
index 77df6c2e2f..4383506ffd 100644
--- a/src/add-ons/accelerants/nvidia/engine/nv_info.c
+++ b/src/add-ons/accelerants/nvidia/engine/nv_info.c
@@ -313,7 +313,7 @@ static void detect_panels()
* are used!
* Currently we'd loose the panel setup while not being able to restore it. */
/* Note:
* NV11 cards can't distinquish between head 1 and head 2. */
if (slaved_for_dev1 && !tvout1)
{
uint16 width = ((DACR(FP_HDISPEND) & 0x0000ffff) + 1);
@@ -326,7 +326,8 @@ static void detect_panels()
si->ps.panel1_height = height;
}
}
- if ((si->ps.card_type != NV11) &&
+ //fixme?!?: how about NV18??, CRTC2 has panel instead of CRTC1???
+ if ((si->ps.card_type != NV11) && (si->ps.card_type != NV17) &&
si->ps.secondary_head && slaved_for_dev2 && !tvout2)
{
uint16 width = ((DAC2R(FP_HDISPEND) & 0x0000ffff) + 1);
@@ -351,7 +352,8 @@ static void detect_panels()
si->ps.panel1_height = height;
}
}
- if ((si->ps.card_type != NV11) &&
+ //fixme?!?: how about NV18??, CRTC2 has panel instead of CRTC1???
+ if ((si->ps.card_type != NV11) && (si->ps.card_type != NV17) &&
si->ps.secondary_head && !si->ps.slaved_tmds2 && !tvout2)
{
uint16 width = ((DAC2R(FP_HDISPEND) & 0x0000ffff) + 1);
@@ -313,7 +313,7 @@ static void detect_panels()
* Currently we'd loose the panel setup while not being able to restore it. */
/* Note:
- * NV11 cards can't distinquish between head 1 and head 2. */
+ * NV11 and NV17 cards can't distinquish between head 1 and head 2. */
if (slaved_for_dev1 && !tvout1)
{